# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.payment_transaction_response import PaymentTransactionResponse

class TestPaymentTransactionResponse(unittest.TestCase):
    """PaymentTransactionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaymentTransactionResponse:
        """Test PaymentTransactionResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaymentTransactionResponse`
        """
        model = PaymentTransactionResponse()
        if include_optional:
            return PaymentTransactionResponse(
                object = 'payment_transaction',
                id = '',
                livemode = True,
                resource_id = '',
                amount = 56,
                currency = 'jpy',
                fee_rate = ERROR_TO_EXAMPLE_VALUE,
                fee = 56,
                type = 'payment',
                payment_method_type = 'card',
                term_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return PaymentTransactionResponse(
                id = '',
                livemode = True,
                resource_id = '',
                amount = 56,
                currency = 'jpy',
                fee_rate = ERROR_TO_EXAMPLE_VALUE,
                fee = 56,
                type = 'payment',
                payment_method_type = 'card',
                term_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testPaymentTransactionResponse(self):
        """Test PaymentTransactionResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
