# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.setup_flow_create_request import SetupFlowCreateRequest

class TestSetupFlowCreateRequest(unittest.TestCase):
    """SetupFlowCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SetupFlowCreateRequest:
        """Test SetupFlowCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SetupFlowCreateRequest`
        """
        model = SetupFlowCreateRequest()
        if include_optional:
            return SetupFlowCreateRequest(
                customer_id = '',
                payment_method_options = payjpv2.models.setup_flow_payment_method_options_request.SetupFlowPaymentMethodOptionsRequest(
                    card = payjpv2.models.setup_flow_payment_method_options_card_request.SetupFlowPaymentMethodOptionsCardRequest(
                        request_three_d_secure = 'automatic', ), ),
                payment_method_types = [
                    'card'
                    ],
                usage = 'on_session',
                description = '',
                metadata = {
                    'key' : null
                    }
            )
        else:
            return SetupFlowCreateRequest(
        )
        """

    def testSetupFlowCreateRequest(self):
        """Test SetupFlowCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
