# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.api.products_api import ProductsApi


class TestProductsApi(unittest.TestCase):
    """ProductsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProductsApi()

    def tearDown(self) -> None:
        pass

    def test_create_product(self) -> None:
        """Test case for create_product

        Create Product
        """
        pass

    def test_delete_product(self) -> None:
        """Test case for delete_product

        Delete Product
        """
        pass

    def test_get_all_products(self) -> None:
        """Test case for get_all_products

        Get All Products
        """
        pass

    def test_get_product(self) -> None:
        """Test case for get_product

        Get Product
        """
        pass

    def test_update_product(self) -> None:
        """Test case for update_product

        Update Product
        """
        pass


if __name__ == '__main__':
    unittest.main()
