# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.payment_method_card_details_response import PaymentMethodCardDetailsResponse

class TestPaymentMethodCardDetailsResponse(unittest.TestCase):
    """PaymentMethodCardDetailsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaymentMethodCardDetailsResponse:
        """Test PaymentMethodCardDetailsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaymentMethodCardDetailsResponse`
        """
        model = PaymentMethodCardDetailsResponse()
        if include_optional:
            return PaymentMethodCardDetailsResponse(
                last4 = '',
                brand = '',
                exp_month = 56,
                exp_year = 56,
                fingerprint = '',
                country = ''
            )
        else:
            return PaymentMethodCardDetailsResponse(
                last4 = '',
                brand = '',
                exp_month = 56,
                exp_year = 56,
                fingerprint = '',
                country = '',
        )
        """

    def testPaymentMethodCardDetailsResponse(self):
        """Test PaymentMethodCardDetailsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
